aboutsummaryrefslogtreecommitdiff
path: root/messages.go
diff options
context:
space:
mode:
authorDimitri Sokolyuk <demon@dim13.org>2015-12-10 14:17:23 +0100
committerDimitri Sokolyuk <demon@dim13.org>2015-12-10 14:17:23 +0100
commit32215b65656e77c2064fd0f0318bbc30ca96ce29 (patch)
tree10b58e34b0806a48eb6ca4c6aa3bc5dcd2986dec /messages.go
parent180dda5b51fafcc972ece0f4cfedc25a615e3ecb (diff)
WIP
Diffstat (limited to 'messages.go')
-rw-r--r--messages.go7
1 files changed, 5 insertions, 2 deletions
diff --git a/messages.go b/messages.go
index 28d531b..18fe0fb 100644
--- a/messages.go
+++ b/messages.go
@@ -9,8 +9,8 @@ import (
const (
// LEV1 Let's Encrytpt V1
LEV1 = `https://acme-v01.api.letsencrypt.org/directory`
- // LEStaging Let's Encrypt Staging
- LEStaging = `https://acme-staging.api.letsencrypt.org/directory`
+ // LES Let's Encrypt Staging
+ LES = `https://acme-staging.api.letsencrypt.org/directory`
)
// Directory ...
@@ -83,8 +83,10 @@ type Problem struct {
Instance string `json:"instance"`
}
+// Status of request
type Status int
+// Statuses
const (
StatusUnknown Status = iota
StatusPending
@@ -94,6 +96,7 @@ const (
StatusRevoked
)
+// UnmarshalJSON implemets json interface for status decoding
func (s *Status) UnmarshalJSON(b []byte) error {
var status = map[string]Status{
"unknown": StatusUnknown,